@@ -6,12 +6,12 @@
 
 import sys
 import os
-# _PATH_HERE = os.path.dirname(__file__)
-# _PATH_PROJ = os.path.dirname(os.path.dirname(_PATH_HERE))
-# _PATH_DS = os.path.join(_PATH_PROJ, 'datastock')
-# sys.path.insert(0, _PATH_DS)
+_PATH_HERE = os.path.dirname(__file__)
+_PATH_PROJ = os.path.dirname(os.path.dirname(_PATH_HERE))
+_PATH_DS = os.path.join(_PATH_PROJ, 'datastock')
+sys.path.insert(0, _PATH_DS)
 import datastock as ds
-# sys.path.pop(0)
+sys.path.pop(0)
 
 # ######################
 # Debugging unit tests - END
