@@ -7,18 +7,11 @@ import warnings
 
 # Common
 import numpy as np
-from scipy.spatial import ConvexHull
-from matplotlib.path import Path
-from contourpy import contour_generator
 import datastock as ds
 
 
 # tofu
 # from . import _class02_checks as _checks
-from . import _class02_bsplines_rect
-from . import _class02_bsplines_tri
-from . import _class02_bsplines_polar
-from . import _class02_bsplines_1d
 from . import _utils_bsplines
 
 
@@ -44,6 +37,7 @@ def interpolate(
     domain=None,
     # common ref
     ref_com=None,
+    ref_vector_strategy=None,
     # bsplines-specific
     details=None,
     indbs_tf=None,
@@ -59,6 +53,7 @@ def interpolate(
     returnas=None,
     return_params=None,
     store=None,
+    store_keys=None,
     inplace=None,
     # debug or unit tests
     debug=None,
@@ -263,6 +258,7 @@ def interpolate(
         domain=domain,
         # common ref
         ref_com=ref_com,
+        # ref_vector_strategy=ref_vector_strategy,
         # parameters
         grid=grid,
         deg=None,
@@ -341,8 +337,21 @@ def interpolate(
     # adjust data and ref if xunique
 
     if xunique:
+        # try:
         ds._class1_interpolate._xunique(dout)
-
+        # except Exception as err:
+        #     msg = (
+        #         err.args[0]
+        #         + "\n\n"
+        #         f"keys = {keys}\n"
+        #         f"ref_key = {ref_key}\n"
+        #         f"x0 = {x0}\n"
+        #         f"x1 = {x1}\n"
+        #     )
+        #     err.args = (msg,)
+        #     raise err
+            
+            
     # ----------
     # store
 
@@ -351,6 +360,7 @@ def interpolate(
             coll=coll,
             dout=dout,
             inplace=inplace,
+            store_keys=store_keys,
         )
 
     # -------
