@@ -32,6 +32,7 @@ def plot_as_profile2d(
     # ref vectors
     dref_vectorZ=None,
     dref_vectorU=None,
+    ref_vector_strategy=None,
     # interpolation
     val_out=None,
     nan0=None,
@@ -137,6 +138,7 @@ def plot_as_profile2d(
                 keybs=v0['keybs'],
                 # ref vector
                 dref_vector=dref_vectorZ,
+                ref_vector_strategy=ref_vector_strategy,
                 # details
                 plot_details=plot_details,
                 # plotting
@@ -739,6 +741,7 @@ def _plot_submesh(
     keybs=None,
     # ref vetcor
     dref_vector=None,
+    ref_vector_strategy=None,
     # plot_details
     plot_details=None,
     # figure
@@ -802,10 +805,19 @@ def _plot_submesh(
         keybs=keybs,
         collax=collax,
         dref_vector=dref_vector,
+        ref_vector_strategy=ref_vector_strategy,
         plot_details=plot_details,
     )
 
-    assert (reft is not None) == ('Z' in dgroup.keys())
+    if (reft is not None) != ('Z' in dgroup.keys()):
+        msg = (
+            "(reft is not None) != ('Z' in dgroup.keys()):\n"
+            f"reft = {reft}\n"
+            f"dgroup.keys() = {dgroup.keys()}\n"
+            f"dref_vector = {dref_vector}"
+        )
+        raise Exception(msg)
+    
     if reft is not None and reft not in dgroup['Z']['ref']:
         dgroup['Z']['ref'].append(reft)
         dgroup['Z']['data'].append('index')
@@ -897,6 +909,7 @@ def _plot_profile2d_polar_add_radial(
     collax=None,
     # ref_vector
     dref_vector=None,
+    ref_vector_strategy=None,
     # details
     plot_details=None,
 ):
@@ -958,6 +971,7 @@ def _plot_profile2d_polar_add_radial(
     reft, keyt, _, dind = coll.get_ref_vector_common(
         keys=[key, kr2d],
         ref=refc,
+        strategy=ref_vector_strategy,
         **dref_vector,
     )[1:]
 
