@@ -400,17 +400,33 @@ def _sample_mesh(bsplines, nd=None, kind=None):
 
     lres = [0.1, 0.3]
     lmode = ['abs', 'rel']
+    lin_mesh = [False, True]
     limshow = [False, True]
 
+    Dx0, Dx1 = None, None
     for km in lkm:
+        for ii, comb in enumerate(itt.product(lres, lmode, lin_mesh, limshow)):
+
+            if nd == '2d':
+                if comb[1] == 'abs' and ii % 3 == 0:
+                    Dx0 = np.r_[2., 3., 2.5]
+                    Dx1 = np.r_[-1, -1, 1]
+                elif comb[1] == 'abs' and ii % 3 == 1:
+                    Dx0 = [None, 2.5]
+                    Dx1 = [-0.5, None]
+                else:
+                    Dx0 = None
+                    Dx1 = None
 
-        for comb in itt.product(lres, lmode, limshow):
             out = bsplines.get_sample_mesh(
                 key=km,
                 res=comb[0],
                 mode=comb[1],
                 grid=None,
-                imshow=comb[2]
+                Dx0=Dx0,
+                Dx1=Dx1,
+                in_mesh=comb[2] and kind != 'tri',
+                imshow=comb[3]
             )
 
 
@@ -770,8 +786,6 @@ def _interpolate(bs, nd=None, kind=None, details=None, submesh=None):
 
 def _bin_bs(bs, nd=None, kind=None):
     dkd = _get_data(bs, nd=nd, kind=kind, maxref=3)
-
-
     wbs = bs._which_bsplines
     for ii, (kd, vd) in enumerate(dkd.items()):
 
@@ -801,21 +815,22 @@ def _bin_bs(bs, nd=None, kind=None):
         bins = np.linspace(vect[0] - 0.1*DD, vect[0]+0.5*DD, nbins)
 
         dout = bs.binning(
-            keys=kd,
-            ref_key=ref_key,
-            bins=bins,
+            data=kd,
+            bin_data0=ref_key,
+            bins0=bins,
             # store vs return
             store=False,
             returnas=True,
         )
+        kd = list(dout.keys())[0]
 
         shape = list(bs.ddata[kd]['shape'])
-        shape[ax] = nbins - 1
+        shape[ax] = nbins
         shape = tuple(shape)
         if dout[kd]['data'].shape != shape:
             shd = bs.ddata[kd]['data'].shape
             msg = (
-                "Binnign of data '{kd}' along ref 'ref_key' has wrong shape:\n"
+                "Binning of data '{kd}' along ref 'ref_key' has wrong shape:\n"
                 f"\t- ddata['{kd}']['data'].shape = {shd}\n"
                 f"\t- dout['{kd}']['data'].shape = {dout[kd]['data'].shape}\n"
                 f"\t- expected shape = {shape}\n"
